@@ -21,6 +21,7 @@ import re
 import time
 from pprint import pprint
 from tinyurl import tiny
+from parsetime import parsetime
 from httplib import BadStatusLine
 from urllib2 import HTTPError
 
@@ -61,8 +62,9 @@ class Feed2Twitter(object):
                 self.rss.updateLastRead(it)
                 print "status: ", status.text
                 time.sleep(5)
+
             except (BadStatusLine, HTTPError):
-                #lets try in the nex ttime
+                #lets try in the next time
                 return
 
     def update(self):
@@ -74,21 +76,27 @@ class Feed2Twitter(object):
             self.twitIt(reversed(lista[:5]))
 
 def update():
-    c = ConfigParser()
+    conf = ConfigParser()
     configfile =os.path.expanduser('~/.feed2twitter/default.cfg')
     try:
         fd =  open(configfile, 'r')
     except IOError:
         print >>sys.stderr, "File %s not found" % configfile
         sys.exit(2)
-    c.readfp(fd)
+    conf.readfp(fd)
 
 
-    url = c.get("global", "url").strip()
-    username = c.get("global", "username").strip()
-    password = c.get("global", "password").strip()
-    mode = c.get("global","mode").strip()
-
-
-    feed2tw = Feed2Twitter(url, username, password, mode)
-    feed2tw.update()
+    url = conf.get("global", "url").strip()
+    username = conf.get("global", "username").strip()
+    password = conf.get("global", "password").strip()
+    mode = conf.get("global","mode").strip()
+    try:
+        interval = parsetime(conf.get("global","interval").strip())
+    except:
+        print('Error in the interval setting')
+        sys.exit(1)
+    print(interval)
+    while True:
+        feed2tw = Feed2Twitter(url, username, password, mode)
+        feed2tw.update()
+        time.sleep(interval)
